@@ -17,13 +17,16 @@ osm_elevation <- function (dat, elev_file) {
 
     if (!"raster" %in% loadedNamespaces ()) {
         requireNamespace ("raster")
-        message ("Elevation data from Consortium for Spatial Information; ",
-                 "see http://srtm.csi.cgiar.org/srtmdata/")
+        message (
+            "Elevation data from Consortium for Spatial Information; ",
+            "see http://srtm.csi.cgiar.org/srtmdata/"
+        )
     }
 
     elev_file <- check_elev_file (elev_file)
-    if (length (elev_file) > 1)
+    if (length (elev_file) > 1) {
         stop ("not yet")
+    }
     r <- raster::raster (elev_file)
     check_bbox (dat, r)
 
@@ -36,8 +39,9 @@ osm_elevation <- function (dat, elev_file) {
 
 check_elev_file <- function (elev_file) {
 
-    if (!methods::is (elev_file, "character"))
+    if (!methods::is (elev_file, "character")) {
         stop ("elev_file must be one of more character strings")
+    }
 
     base_dir <- dirname (elev_file [1])
     lf <- list.files (base_dir, full.names = TRUE)
@@ -45,20 +49,25 @@ check_elev_file <- function (elev_file) {
 
     for (f in elev_file) {
 
-        if (!file.exists (f))
+        if (!file.exists (f)) {
             stop ("file ", f, " does not exist")
+        }
 
         fe <- tools::file_ext (f)
-        if (!fe %in% c ("tif", "zip"))
+        if (!fe %in% c ("tif", "zip")) {
             stop ("Unrecognised file format [.", fe, "]; must be .zip or .tif")
+        }
 
         if (fe == "zip") {
 
             ftif <- paste0 (basename (tools::file_path_sans_ext (f)), ".tif")
             index <- grepl (ftif, lf, ignore.case = TRUE)
             if (!any (index)) {
-                message ("File ", f, " has not been unzipped; ",
-                         "this may take a while ... ", appendLF = FALSE)
+                message (
+                    "File ", f, " has not been unzipped; ",
+                    "this may take a while ... ",
+                    appendLF = FALSE
+                )
                 utils::unzip (f, exdir = base_dir)
                 message ("done.")
                 lf <- list.files (base_dir, full.names = TRUE)
@@ -66,8 +75,9 @@ check_elev_file <- function (elev_file) {
             }
 
             ret <- c (ret, lf [which (index)])
-        } else
+        } else {
             ret <- c (ret, f)
+        }
     }
 
     return (unique (ret))
@@ -82,8 +92,9 @@ check_bbox <- function (dat, r) {
     if (bb [1, 1] < bbr [1, 1] |
         bb [1, 2] > bbr [1, 2] |
         bb [2, 1] < bbr [2, 1] |
-        bb [2, 2] > bbr [2, 2])
+        bb [2, 2] > bbr [2, 2]) {
         message ("Elevation file does not cover OSM data file")
+    }
 }
 
 # elevation tiles from http://srtm.csi.cgiar.org/srtmdata
@@ -100,9 +111,11 @@ get_tile_index <- function (bb) {
     yi_min <- 14 + floor (bb [1] / 5)
     yi_max <- 14 + floor (bb [3] / 5)
 
-    xi <- unique (c (xi_min, xi_max))
-    yi <- unique (c (yi_min, yi_max))
+    xi <- as.integer (unique (c (xi_min, xi_max)))
+    yi <- as.integer (unique (c (yi_min, yi_max)))
 
-    data.frame ("xi" = rep (xi, each = length (yi)),
-                       "yi" = rep (yi, times = length (xi)))
+    data.frame (
+        "xi" = rep (xi, each = length (yi)),
+        "yi" = rep (yi, times = length (xi))
+    )
 }
