@@ -17,12 +17,3 @@ vg_check <- function () {
 
     return (TRUE)
 }
-
-if (identical (Sys.getenv ("TRAVIS"), "true")) {
-
-    #library (osmdata)
-    #chk <- opq ("hampi india") %>%
-    #    add_osm_feature (key = "highway") %>%
-    #    osmdata_xml ("hampi.osm")
-    #vg_check ()
-}
